.. Copyright 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.component.exceptions
---------------------------------

.. automodule:: reahl.component.exceptions

DomainException
"""""""""""""""

.. autoclass:: DomainException
   :members:

AccessRestricted
""""""""""""""""

.. autoclass:: AccessRestricted
   :members:

ProgrammerError
"""""""""""""""

.. autoclass:: ProgrammerError
   :members:

IncorrectArgumentError
""""""""""""""""""""""

.. autoclass:: IncorrectArgumentError
   :members:




